Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1848)

Unified Diff: runtime/vm/stub_code_arm64.cc

Issue 2719603002: Rename Closure instance field type_arguments_ to instantiator_. (Closed)
Patch Set: work in progress Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « runtime/vm/stub_code_arm.cc ('k') | runtime/vm/stub_code_ia32.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/vm/stub_code_arm64.cc
diff --git a/runtime/vm/stub_code_arm64.cc b/runtime/vm/stub_code_arm64.cc
index 63ceedd02c3e183a9c5105afe1ff09b11fd833cb..4e2293b73c8b2b89d4779052f089518984d79042 100644
--- a/runtime/vm/stub_code_arm64.cc
+++ b/runtime/vm/stub_code_arm64.cc
@@ -1815,10 +1815,11 @@ static void GenerateSubtypeNTestCacheStub(Assembler* assembler, int n) {
Label loop, found, not_found, next_iteration;
// R2: entry start.
// R3: instance class id.
// R4: instance type arguments.
__ SmiTag(R3);
__ CompareImmediate(R3, Smi::RawValue(kClosureCid));
__ b(&loop, NE);
+ __ LoadFieldFromOffset(R4, R0, Closure::instantiator_offset());
__ LoadFieldFromOffset(R3, R0, Closure::function_offset());
// R3: instance class id as Smi or function.
__ Bind(&loop);
@@ -1815,10 +1815,11 @@ static void GenerateSubtypeNTestCacheStub(Assembler* assembler, int n) {
// R2: entry start.
// R3: instance class id.
- // R4: instance type arguments.
+ // R4: instance type arguments (still null if closure).
__ SmiTag(R3);
__ CompareImmediate(R3, Smi::RawValue(kClosureCid));
« no previous file with comments | « runtime/vm/stub_code_arm.cc ('k') | runtime/vm/stub_code_ia32.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698